@@ -292,96 +292,3 @@ class EventStorage(object):
         Clear data.
         """
         pass
-
-
-@add_metaclass(abc.ABCMeta)
-class TelemetryStorage(object):
-    """Telemetry storage interface."""
-
-    @abc.abstractmethod
-    def inc_latency(self, name, bucket):
-        """
-        Add a latency.
-
-        :param name: Name of the latency metric.
-        :type name: str
-        :param value: Value of the latency metric.
-        :tyoe value: int
-        """
-        pass
-
-    @abc.abstractmethod
-    def inc_counter(self, name):
-        """
-        Increment a counter.
-
-        :param name: Name of the counter metric.
-        :type name: str
-        """
-        pass
-
-    @abc.abstractmethod
-    def put_gauge(self, name, value):
-        """
-        Add a gauge metric.
-
-        :param name: Name of the gauge metric.
-        :type name: str
-        :param value: Value of the gauge metric.
-        :type value: int
-        """
-        pass
-
-    @abc.abstractmethod
-    def pop_counters(self):
-        """
-        Get all the counters.
-
-        :rtype: list
-        """
-        pass
-
-    @abc.abstractmethod
-    def pop_gauges(self):
-        """
-        Get all the gauges.
-
-        :rtype: list
-
-        """
-        pass
-
-    @abc.abstractmethod
-    def pop_latencies(self):
-        """
-        Get all latencies.
-
-        :rtype: list
-        """
-        pass
-
-    @abc.abstractmethod
-    def clear(self):
-        """
-        Clear data.
-        """
-        pass
-
-
-@add_metaclass(abc.ABCMeta)
-class TelemetryPipelinedStorage(object):
-    """Telemetry Pipelined Storage interface."""
-
-    @abc.abstractmethod
-    def add_latency_to_pipe(self, latency, operation, pipe):
-        """
-        Add latency operation to pipeline
-
-        :param latency: time took for doing evaluation
-        :type latency: int
-        :param operation: operation type
-        :type operation: str
-        :param pipe: Redis pipe.
-        :type pipe: redis.pipe
-        """
-        pass
